OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Details",
    "Rename" : "Rename",
    "Move" : "Move",
    "Delete" : "Delete",
    "Select all" : "Select all",
    "New" : "New",
    "New folder" : "New folder",
    "Search" : "Search",
    "Delete folder" : "Delete folder",
    "Cancel" : "Cancel",
    "Recent" : "Recent",
    "Shared with you" : "Shared with you",
    "Files" : "Files",
    "Link" : "Link",
    "Tags" : "Tags",
    "Notes" : "Notes",
    "Download file" : "Download file",
    "Owner" : "Owner",
    "Sharing" : "Ulashish",
    "Share link" : "Share link",
    "Allow editing" : "Allow editing",
    "Save" : "Save"
},
"nplurals=1; plural=0;");
